
package Paws::DS::DisableRadiusResult;
  use Moose;


### main pod documentation begin ###

=head1 NAME

Paws::DS::DisableRadiusResult

=head1 ATTRIBUTES



=cut

1;